@@ -173,26 +173,6 @@ class FiltrationData(BaseModel):
     def set_default(cls, attr, value):
         cls._default[attr] = value
 
-    @classmethod
-    @validator("page_size", pre=True, always=True)
-    def _pre_validate_page_size(cls, page_size: Optional[int]) -> int:
-        print("page_size")
-        return page_size or cls.__get_default("page_size")
-
-    @classmethod
-    @validator("order_by", pre=True, always=True)
-    def _pre_validate_order_by(cls, order_by: Optional[str]) -> Optional[str]:
-        print("order_by")
-        return order_by or cls.__get_default("order_by")
-
-    @classmethod
-    @validator("sort_by", pre=True, always=True)
-    def _pre_validate_sort_by(
-        cls, sort_by: Optional[Literal["asc", "desc"]]
-    ) -> Literal["asc", "desc"]:
-        print("sort_by")
-        return sort_by or cls.__get_default("sort_by")
-
     def __get_sort_spec(self) -> list[ModelSortSpec]:
         return [_split_field(self.order_by) | {"direction": self.sort_by}]  # type: ignore
 
