@@ -1,7 +1,7 @@
 from __future__ import annotations
 from functools import cache
 
-from typing import Callable, Iterable, Union, Literal, Optional, cast
+from typing import Any, Callable, Iterable, Union, Literal, Optional, cast
 from fastapi import Request, HTTPException, Query
 from starlette.datastructures import QueryParams
 from abc import ABC, abstractmethod
@@ -210,18 +210,11 @@ class LHSQueryParser(QueryParser):
 
 AnyFiltrationOperator = Union[FiltrationOperator, str]
 
-GlobalDefaultFiltrationClass = FiltrationData
-
-
-def set_default_filtration_class(filtration: type[FiltrationData]) -> None:
-    global GlobalDefaultFiltrationClass
-    GlobalDefaultFiltrationClass = filtration
-
 
 def get_filtration(
     valid_columns: Iterable[str],
     *,
-    default_filtration_class: Optional[type[FiltrationData]] = None,
+    default_filtration_class: type[FiltrationData] = FiltrationData,
     operator_data: Optional[
         dict[
             str,
@@ -260,8 +253,8 @@ def get_filtration(
     def get_filtration_data(
         request: Request,
         *,
-        limit: Optional[int] = None,
-        offset: Optional[int] = None,
+        page_number: Optional[int] = None,
+        page_size: Optional[int] = None,
         order_by: Optional[str] = None,
         sort_by: Literal["asc", "desc"] = "asc",
         **kwargs,
@@ -273,12 +266,16 @@ def get_filtration(
                 f"Valid columns: {', '.join(valid_columns)}",
             )
 
-        return (default_filtration_class or GlobalDefaultFiltrationClass)(
-            to_filter=parser.parse(request.query_params),
-            limit=limit,
-            offset=offset,
-            order_by=order_by,
-            sort_by=sort_by,
+        _kwargs: dict[str, Any] = dict(
+            to_filter=parser.parse(request.query_params), sort_by=sort_by
         )
+        if page_number is not None:
+            _kwargs["page_number"] = page_number
+        if page_size is not None:
+            _kwargs["page_size"] = page_size
+        if order_by is not None:
+            _kwargs["order_by"] = order_by
+
+        return default_filtration_class(**_kwargs)
 
     return get_filtration_data
