@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Callable, TypeVar, Generic
+from typing import Callable, Iterator, TypeVar, Generic
 from pydantic.generics import GenericModel
 from pydantic import BaseModel
 
